import { Module } from '@nestjs/common';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { TypeOrmModule } from '@nestjs/typeorm';
import { AdminController } from './admin/admin.controller';
import { ConfigModule, ConfigService } from '@nestjs/config';
import { App } from './entities/App.entity';
import { AppHistory } from './entities/AppHistory.entity';
import { S3Service } from './s3/s3.service';
import { PackagerService } from './packager/packager.service';
import { AssetsS3Service } from './assets-s3/assets-s3.service';
import { PackageS3Service } from './package-s3/package-s3.service';

const configModule = ConfigModule.forRoot();

@Module({
  imports: [
    configModule,
    TypeOrmModule.forRootAsync({
      name: 'app',
      imports: [configModule],
      inject: [ConfigService],
      useFactory: async (config: ConfigService) => {
        return {
          type: 'postgres',
          entities: [App, AppHistory], // entities here
          synchronize: !config.get('DB_NO_INIT'),
          host: config.get('DB_HOST'),
          port: parseInt(config.get('DB_PORT')) || 5432,
          username: config.get('DB_USER'),
          password: config.get('DB_PASS'),
          database: config.get('DB_NAME'),
        };
      },
    }),
  ],
  controllers: [AppController, AdminController],
  providers: [AppService, PackagerService, AssetsS3Service, PackageS3Service],
})
export class AppModule {}
